@@ -48,7 +48,7 @@ impl<'a> Endpoint for AddProjectMember<'a> {
 
         params
             .push("user_id", self.user)
-            .push("access_level", self.access_level.as_str())
+            .push("access_level", self.access_level.as_u64())
             .push_opt("expires_at", self.expires_at);
 
         params.into_body()
@@ -57,8 +57,13 @@ impl<'a> Endpoint for AddProjectMember<'a> {
 
 #[cfg(test)]
 mod tests {
+    use chrono::NaiveDate;
+    use http::Method;
+
     use crate::api::common::AccessLevel;
     use crate::api::projects::members::AddProjectMember;
+    use crate::api::{self, Query};
+    use crate::test::client::{ExpectedUrl, SingleTestClient};
 
     #[test]
     fn all_parameters_are_needed() {
@@ -105,4 +110,49 @@ mod tests {
             .build()
             .unwrap();
     }
+
+    #[test]
+    fn endpoint() {
+        let endpoint = ExpectedUrl::builder()
+            .method(Method::POST)
+            .endpoint("projects/simple%2Fproject/members")
+            .content_type("application/x-www-form-urlencoded")
+            .body_str(concat!("user_id=1", "&access_level=30"))
+            .build()
+            .unwrap();
+        let client = SingleTestClient::new_raw(endpoint, "");
+
+        let endpoint = AddProjectMember::builder()
+            .project("simple/project")
+            .user(1)
+            .access_level(AccessLevel::Developer)
+            .build()
+            .unwrap();
+        api::ignore(endpoint).query(&client).unwrap();
+    }
+
+    #[test]
+    fn endpoint_expires_at() {
+        let endpoint = ExpectedUrl::builder()
+            .method(Method::POST)
+            .endpoint("projects/simple%2Fproject/members")
+            .content_type("application/x-www-form-urlencoded")
+            .body_str(concat!(
+                "user_id=1",
+                "&access_level=30",
+                "&expires_at=2020-01-01",
+            ))
+            .build()
+            .unwrap();
+        let client = SingleTestClient::new_raw(endpoint, "");
+
+        let endpoint = AddProjectMember::builder()
+            .project("simple/project")
+            .user(1)
+            .access_level(AccessLevel::Developer)
+            .expires_at(NaiveDate::from_ymd(2020, 1, 1))
+            .build()
+            .unwrap();
+        api::ignore(endpoint).query(&client).unwrap();
+    }
 }
